==> igniteui-react-18.2.2-beta.0.tgz: package/esm5/lib/Rating.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { BaseElement } from "./BaseElement";
import { WCNativeHelper } from "./WCNativeHelper";
import { enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { SizableComponentSize_$type } from "./SizableComponentSize";
import { NumberEventArgs } from "./NumberEventArgs";
/**
 * @hidden
 */
var Rating = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(Rating, _super);
    function Rating() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.d = new WCNativeHelper();
        _this.m = null;
        _this.change = null;
        _this.hover = null;
        return _this;
    }
    Object.defineProperty(Rating.prototype, "e", {
        get: function () {
            return this.d;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Rating.prototype, "nativeElement", {
        get: function () {
            return this.m;
        },
        set: function (a) {
            this.m = a;
            this.d.n = this.m;
        },
        enumerable: false,
        configurable: true
    });
    Rating.prototype.setNativeElement = function (a) {
        this.nativeElement = a;
    };
    Object.defineProperty(Rating.prototype, "j", {
        get: function () {
            var ret_ = this.e.m("max");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.e.u("max", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Rating.prototype, "k", {
        get: function () {
            var ret_ = this.e.m("step");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.e.u("step", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Rating.prototype, "p", {
        get: function () {
            var ret_ = this.e.m("name");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.e.u("name", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Rating.prototype, "o", {
        get: function () {
            var ret_ = this.e.m("label");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.e.u("label", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Rating.prototype, "q", {
        get: function () {
            var ret_ = this.e.m("valueFormat");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.e.u("valueFormat", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Rating.prototype, "l", {
        get: function () {
            var ret_ = this.e.m("value");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.e.u("value", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Rating.prototype, "f", {
        get: function () {
            var ret_ = this.e.m("disabled");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.e.u("disabled", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Rating.prototype, "g", {
        get: function () {
            var ret_ = this.e.m("hoverPreview");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.e.u("hoverPreview", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Rating.prototype, "h", {
        get: function () {
            var ret_ = this.e.m("readonly");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.e.u("readonly", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Rating.prototype, "i", {
        get: function () {
            var ret_ = this.e.m("single");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.e.u("single", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Rating.prototype, "c", {
        get: function () {
            var ret_ = this.e.m("size");
            ret_ = enumGetBox(SizableComponentSize_$type, EnumUtil.getEnumValue(SizableComponentSize_$type, this.e.f(SizableComponentSize_$type, ret_)));
            return EnumUtil.getEnumValue(SizableComponentSize_$type, ret_);
        },
        set: function (a) {
            var value_ = enumGetBox(SizableComponentSize_$type, a);
            value_ = WCNativeHelper.o(value_.toString());
            this.e.u("size", value_);
        },
        enumerable: false,
        configurable: true
    });
    Rating.prototype.changeChanged = function () {
        var _this = this;
        if (this.change != null) {
            this.e.q("change", function (a) { return _this.change(_this, NumberEventArgs.a(a)); });
        }
        else {
            this.e.t("change");
        }
    };
    Rating.prototype.hoverChanged = function () {
        var _this = this;
        if (this.hover != null) {
            this.e.q("hover", function (a) { return _this.hover(_this, NumberEventArgs.a(a)); });
        }
        else {
            this.e.t("hover");
        }
    };
    Rating.prototype.v = function (a) {
        this.nativeElement.stepUp(this.e.h(a));
    };
    Rating.prototype.u = function (a) {
        this.nativeElement.stepDown(this.e.h(a));
    };
    Rating.$t = markType(Rating, 'Rating', BaseElement.$);
    return Rating;
}(BaseElement));
export { Rating };

==> igniteui-react-18.3.0-beta.0.tgz: package/esm5/lib/Rating.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { BaseElement } from "./BaseElement";
import { WCNativeHelper } from "./WCNativeHelper";
import { enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { SizableComponentSize_$type } from "./SizableComponentSize";
import { NumberEventArgs } from "./NumberEventArgs";
/**
 * @hidden
 */
var Rating = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(Rating, _super);
    function Rating() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.d = new WCNativeHelper();
        _this.m = null;
        _this.change = null;
        _this.hover = null;
        return _this;
    }
    Object.defineProperty(Rating.prototype, "e", {
        get: function () {
            return this.d;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Rating.prototype, "nativeElement", {
        get: function () {
            return this.m;
        },
        set: function (a) {
            this.m = a;
            this.d.o = this.m;
        },
        enumerable: false,
        configurable: true
    });
    Rating.prototype.setNativeElement = function (a) {
        this.nativeElement = a;
    };
    Object.defineProperty(Rating.prototype, "j", {
        get: function () {
            var ret_ = this.e.n("max");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.e.v("max", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Rating.prototype, "k", {
        get: function () {
            var ret_ = this.e.n("step");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.e.v("step", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Rating.prototype, "p", {
        get: function () {
            var ret_ = this.e.n("name");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.e.v("name", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Rating.prototype, "o", {
        get: function () {
            var ret_ = this.e.n("label");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.e.v("label", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Rating.prototype, "q", {
        get: function () {
            var ret_ = this.e.n("valueFormat");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.e.v("valueFormat", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Rating.prototype, "l", {
        get: function () {
            var ret_ = this.e.n("value");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.e.v("value", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Rating.prototype, "f", {
        get: function () {
            var ret_ = this.e.n("disabled");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.e.v("disabled", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Rating.prototype, "g", {
        get: function () {
            var ret_ = this.e.n("hoverPreview");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.e.v("hoverPreview", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Rating.prototype, "h", {
        get: function () {
            var ret_ = this.e.n("readonly");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.e.v("readonly", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Rating.prototype, "i", {
        get: function () {
            var ret_ = this.e.n("single");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.e.v("single", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Rating.prototype, "c", {
        get: function () {
            var ret_ = this.e.n("size");
            ret_ = enumGetBox(SizableComponentSize_$type, EnumUtil.getEnumValue(SizableComponentSize_$type, this.e.f(SizableComponentSize_$type, ret_)));
            return EnumUtil.getEnumValue(SizableComponentSize_$type, ret_);
        },
        set: function (a) {
            var value_ = enumGetBox(SizableComponentSize_$type, a);
            value_ = WCNativeHelper.p(value_.toString());
            this.e.v("size", value_);
        },
        enumerable: false,
        configurable: true
    });
    Rating.prototype.changeChanged = function () {
        var _this = this;
        if (this.change != null) {
            this.e.r("change", function (a) { return _this.change(_this, NumberEventArgs.a(a)); });
        }
        else {
            this.e.u("change");
        }
    };
    Rating.prototype.hoverChanged = function () {
        var _this = this;
        if (this.hover != null) {
            this.e.r("hover", function (a) { return _this.hover(_this, NumberEventArgs.a(a)); });
        }
        else {
            this.e.u("hover");
        }
    };
    Rating.prototype.v = function (a) {
        this.nativeElement.stepUp(this.e.i(a));
    };
    Rating.prototype.u = function (a) {
        this.nativeElement.stepDown(this.e.i(a));
    };
    Rating.$t = markType(Rating, 'Rating', BaseElement.$);
    return Rating;
}(BaseElement));
export { Rating };
